pub struct DetachedAccumulatorMembershipProver<E: Pairing> {
pub accumulator_value: E::G1Affine,
pub params: Option<SetupParams<E>>,
pub public_key: Option<PublicKey<E>>,
pub proving_key: Option<MembershipProvingKey<E::G1Affine>>,
pub params_ref: Option<usize>,
pub public_key_ref: Option<usize>,
pub proving_key_ref: Option<usize>,
}Fields
accumulator_value: E::G1Affineparams: Option<SetupParams<E>>public_key: Option<PublicKey<E>>proving_key: Option<MembershipProvingKey<E::G1Affine>>params_ref: Option<usize>public_key_ref: Option<usize>proving_key_ref: Option<usize>Implementations
Sourceimpl<E: Pairing> DetachedAccumulatorMembershipProver<E>
impl<E: Pairing> DetachedAccumulatorMembershipProver<E>
Sourcepub fn new_statement_from_params(
params: AccumParams<E>,
public_key: PublicKey<E>,
proving_key: MembershipProvingKey<E::G1Affine>,
accumulator_value: E::G1Affine,
) -> Statement<E>
pub fn new_statement_from_params( params: AccumParams<E>, public_key: PublicKey<E>, proving_key: MembershipProvingKey<E::G1Affine>, accumulator_value: E::G1Affine, ) -> Statement<E>
Create a statement by passing the accumulator params, public key and proving key directly.
Sourcepub fn new_statement_from_params_ref(
params_ref: usize,
public_key_ref: usize,
proving_key_ref: usize,
accumulator_value: E::G1Affine,
) -> Statement<E>
pub fn new_statement_from_params_ref( params_ref: usize, public_key_ref: usize, proving_key_ref: usize, accumulator_value: E::G1Affine, ) -> Statement<E>
Create a statement by passing the indices of accumulator params, public key and proving key in SetupParams.
Sourcepub fn get_params<'a>(
&'a self,
setup_params: &'a [SetupParams<E>],
st_idx: usize,
) -> Result<&'a AccumParams<E>, ProofSystemError>
pub fn get_params<'a>( &'a self, setup_params: &'a [SetupParams<E>], st_idx: usize, ) -> Result<&'a AccumParams<E>, ProofSystemError>
Get accumulator params for the statement index s_idx either from self or from given setup_params
Sourcepub fn get_public_key<'a>(
&'a self,
setup_params: &'a [SetupParams<E>],
st_idx: usize,
) -> Result<&'a PublicKey<E>, ProofSystemError>
pub fn get_public_key<'a>( &'a self, setup_params: &'a [SetupParams<E>], st_idx: usize, ) -> Result<&'a PublicKey<E>, ProofSystemError>
Get public key for the statement index s_idx either from self or from given setup_params
Sourcepub fn get_proving_key<'a>(
&'a self,
setup_params: &'a [SetupParams<E>],
st_idx: usize,
) -> Result<&'a MembershipProvingKey<E::G1Affine>, ProofSystemError>
pub fn get_proving_key<'a>( &'a self, setup_params: &'a [SetupParams<E>], st_idx: usize, ) -> Result<&'a MembershipProvingKey<E::G1Affine>, ProofSystemError>
Get membership proving key for the statement index s_idx either from self or from given setup_params