pub struct PoKBBSSignature23G1Verifier<E: Pairing> {
pub revealed_messages: BTreeMap<usize, E::ScalarField>,
pub signature_params: Option<SignatureParams23G1<E>>,
pub public_key: Option<PublicKeyG2<E>>,
pub signature_params_ref: Option<usize>,
pub public_key_ref: Option<usize>,
}Fields
revealed_messages: BTreeMap<usize, E::ScalarField>Messages being revealed.
signature_params: Option<SignatureParams23G1<E>>If the statement was created by passing the signature params directly, then it will not be None
public_key: Option<PublicKeyG2<E>>If the statement was created by passing the public key params directly, then it will not be None
signature_params_ref: Option<usize>If the statement was created by passing the index of signature params in SetupParams, then it will not be None
public_key_ref: Option<usize>If the statement was created by passing the index of public key in SetupParams, then it will not be None
Implementations
Sourceimpl<E: Pairing> PoKBBSSignature23G1Verifier<E>
impl<E: Pairing> PoKBBSSignature23G1Verifier<E>
Sourcepub fn new_statement_from_params(
signature_params: SignatureParams23G1<E>,
public_key: PublicKeyG2<E>,
revealed_messages: BTreeMap<usize, E::ScalarField>,
) -> Statement<E>
pub fn new_statement_from_params( signature_params: SignatureParams23G1<E>, public_key: PublicKeyG2<E>, revealed_messages: BTreeMap<usize, E::ScalarField>, ) -> Statement<E>
Create a statement by passing the signature parameters and public key directly.
Sourcepub fn new_statement_from_params_ref(
signature_params_ref: usize,
public_key_ref: usize,
revealed_messages: BTreeMap<usize, E::ScalarField>,
) -> Statement<E>
pub fn new_statement_from_params_ref( signature_params_ref: usize, public_key_ref: usize, revealed_messages: BTreeMap<usize, E::ScalarField>, ) -> Statement<E>
Create a statement by passing the indices of signature parameters and public key in SetupParams.
Sourcepub fn get_params<'a>(
&'a self,
setup_params: &'a [SetupParams<E>],
st_idx: usize,
) -> Result<&'a SignatureParams23G1<E>, ProofSystemError>
pub fn get_params<'a>( &'a self, setup_params: &'a [SetupParams<E>], st_idx: usize, ) -> Result<&'a SignatureParams23G1<E>, ProofSystemError>
Get signature params for the statement index s_idx either from self or from given setup_params.
Sourcepub fn get_public_key<'a>(
&'a self,
setup_params: &'a [SetupParams<E>],
st_idx: usize,
) -> Result<&'a PublicKeyG2<E>, ProofSystemError>
pub fn get_public_key<'a>( &'a self, setup_params: &'a [SetupParams<E>], st_idx: usize, ) -> Result<&'a PublicKeyG2<E>, ProofSystemError>
Get public key for the statement index s_idx either from self or from given setup_params.